From: Yongqiang Sun <yongqiang....@amd.com>

For legacy enable boot up with lid closed, eDP information couldn't be
read correctly via SBIOS_SCRATCH_3 results in eDP cannot be light up
properly when open lid.
Check lid state instead can resolve the issue.

Signed-off-by: Yongqiang Sun <yongqiang....@amd.com>
Reviewed-by: Eric Yang <eric.ya...@amd.com>
Acked-by: Harry Wentland <harry.wentl...@amd.com>
---
 drivers/gpu/drm/amd/display/dc/dc_stream.h         |  1 +
 .../amd/display/dc/dce110/dce110_hw_sequencer.c    | 24 ++++++++++++++--------
 2 files changed, 17 insertions(+), 8 deletions(-)

diff --git a/drivers/gpu/drm/amd/display/dc/dc_stream.h 
b/drivers/gpu/drm/amd/display/dc/dc_stream.h
index 046e87aa699a..5f215ca38c07 100644
--- a/drivers/gpu/drm/amd/display/dc/dc_stream.h
+++ b/drivers/gpu/drm/amd/display/dc/dc_stream.h
@@ -98,6 +98,7 @@ struct dc_stream_state {
        int phy_pix_clk;
        enum signal_type signal;
        bool dpms_off;
+       bool lid_state_closed;
 
        struct dc_stream_status status;
 
diff --git a/drivers/gpu/drm/amd/display/dc/dce110/dce110_hw_sequencer.c 
b/drivers/gpu/drm/amd/display/dc/dce110/dce110_hw_sequencer.c
index 0ff2a8092782..3ba057e2a467 100644
--- a/drivers/gpu/drm/amd/display/dc/dce110/dce110_hw_sequencer.c
+++ b/drivers/gpu/drm/amd/display/dc/dce110/dce110_hw_sequencer.c
@@ -1481,6 +1481,17 @@ static void disable_vga_and_power_gate_all_controllers(
        }
 }
 
+static bool is_eDP_lid_closed(struct dc_state *context)
+{
+       int i;
+
+       for (i = 0; i < context->stream_count; i++) {
+               if (context->streams[i]->signal == SIGNAL_TYPE_EDP)
+                       return context->streams[i]->lid_state_closed;
+       }
+       return false;
+}
+
 static struct dc_link *get_link_for_edp_not_in_use(
                struct dc *dc,
                struct dc_state *context)
@@ -1515,20 +1526,17 @@ static struct dc_link *get_link_for_edp_not_in_use(
  */
 void dce110_enable_accelerated_mode(struct dc *dc, struct dc_state *context)
 {
-       struct dc_bios *dcb = dc->ctx->dc_bios;
-
-       /* vbios already light up eDP, so we can leverage vbios and skip eDP
+       /* check eDP lid state:
+        * If lid is open, vbios already light up eDP, so we can leverage vbios 
and skip eDP
         * programming
         */
-       bool can_eDP_fast_boot_optimize =
-                       (dcb->funcs->get_vga_enabled_displays(dc->ctx->dc_bios) 
== ATOM_DISPLAY_LCD1_ACTIVE);
-
-       /* if OS doesn't light up eDP and eDP link is available, we want to 
disable */
+       bool lid_state_closed = is_eDP_lid_closed(context);
        struct dc_link *edp_link_to_turnoff = NULL;
 
-       if (can_eDP_fast_boot_optimize) {
+       if (!lid_state_closed) {
                edp_link_to_turnoff = get_link_for_edp_not_in_use(dc, context);
 
+               /* if OS doesn't light up eDP and eDP link is available, we 
want to disable */
                if (!edp_link_to_turnoff)
                        dc->apply_edp_fast_boot_optimization = true;
        }
-- 
2.15.1

_______________________________________________
amd-gfx mailing list
amd-gfx@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/amd-gfx

Reply via email to